package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.ReceptionPersonnelMapper;
import com.ruoyi.system.domain.ReceptionPersonnel;
import com.ruoyi.system.service.IReceptionPersonnelService;

/**
 * 接待人员信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-11-02
 */
@Service
public class ReceptionPersonnelServiceImpl implements IReceptionPersonnelService 
{
    @Autowired
    private ReceptionPersonnelMapper receptionPersonnelMapper;

    /**
     * 查询接待人员信息
     * 
     * @param receptionId 接待人员信息主键
     * @return 接待人员信息
     */
    @Override
    public ReceptionPersonnel selectReceptionPersonnelByReceptionId(Long receptionId)
    {
        return receptionPersonnelMapper.selectReceptionPersonnelByReceptionId(receptionId);
    }

    /**
     * 查询接待人员信息列表
     * 
     * @param receptionPersonnel 接待人员信息
     * @return 接待人员信息
     */
    @Override
    public List<ReceptionPersonnel> selectReceptionPersonnelList(ReceptionPersonnel receptionPersonnel)
    {
        return receptionPersonnelMapper.selectReceptionPersonnelList(receptionPersonnel);
    }

    /**
     * 新增接待人员信息
     * 
     * @param receptionPersonnel 接待人员信息
     * @return 结果
     */
    @Override
    public int insertReceptionPersonnel(ReceptionPersonnel receptionPersonnel)
    {
        receptionPersonnel.setCreateTime(DateUtils.getNowDate());
        return receptionPersonnelMapper.insertReceptionPersonnel(receptionPersonnel);
    }

    /**
     * 修改接待人员信息
     * 
     * @param receptionPersonnel 接待人员信息
     * @return 结果
     */
    @Override
    public int updateReceptionPersonnel(ReceptionPersonnel receptionPersonnel)
    {
        receptionPersonnel.setUpdateTime(DateUtils.getNowDate());
        return receptionPersonnelMapper.updateReceptionPersonnel(receptionPersonnel);
    }

    /**
     * 批量删除接待人员信息
     * 
     * @param receptionIds 需要删除的接待人员信息主键
     * @return 结果
     */
    @Override
    public int deleteReceptionPersonnelByReceptionIds(Long[] receptionIds)
    {
        return receptionPersonnelMapper.deleteReceptionPersonnelByReceptionIds(receptionIds);
    }

    /**
     * 删除接待人员信息信息
     * 
     * @param receptionId 接待人员信息主键
     * @return 结果
     */
    @Override
    public int deleteReceptionPersonnelByReceptionId(Long receptionId)
    {
        return receptionPersonnelMapper.deleteReceptionPersonnelByReceptionId(receptionId);
    }
}
